#
# spec file for package gstreamer-docs
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         gst_branch      1.0

Name:           gstreamer-docs
Version:        1.26.1
Release:        1.1
Summary:        GStreamer documentation
License:        (BSD-2-Clause OR LGPL-2.1-or-later OR MIT) AND OPL-1.0 AND CC-BY-SA-4.0

#  Tutorial source code:
#  All tutorial code is licensed under any of the following licenses (your choice):
#  2-clause BSD license ("simplified BSD license") (LICENSE.BSD)
#  MIT license (LICENSE.MIT)
#  LGPL v2.1 (LICENSE.LGPL-2.1)
#  Application Developer Manual and Plugin Writer's Guide:
#  Open Publication License v1.0 (LICENSE.OPL), for historical reasons.
#  Documentation:
#  Creative Commons CC-BY-SA-4.0 license, but some parts of the documentation
#  may still be licensed differently (e.g. LGPLv2.1) for historical reasons.

URL:            https://gstreamer.freedesktop.org/
Source:         %{url}/src/%{name}/%{name}-%{version}.tar.xz

BuildRequires:  fdupes
Obsoletes:      gstreamer-doc < %{version}
Obsoletes:      gstreamer-plugins-bad-doc < %{version}
Obsoletes:      gstreamer-plugins-base-doc < %{version}
Obsoletes:      gstreamer-plugins-good-doc < %{version}
Obsoletes:      gstreamer-plugins-libav-doc < %{version}
Obsoletes:      gstreamer-plugins-ugly-doc < %{version}
Obsoletes:      gstreamer-plugins-vaapi-doc < %{version}
Provides:       gstreamer-doc = %{version}
Provides:       gstreamer-plugins-bad-doc = %{version}
Provides:       gstreamer-plugins-base-doc = %{version}
Provides:       gstreamer-plugins-good-doc = %{version}
Provides:       gstreamer-plugins-libav-doc = %{version}
Provides:       gstreamer-plugins-ugly-doc = %{version}
Provides:       gstreamer-plugins-vaapi-doc = %{version}
BuildArch:      noarch

%description
GStreamer documentation.

%prep
%autosetup

%build

%install

# Move devhelp into the right directory
mkdir -p %{buildroot}%{_datadir}/gtk-doc/html/
cp -r devhelp/books/GStreamer %{buildroot}%{_datadir}/gtk-doc/html/GStreamer-%{gst_branch}

# Remove the search assets, we use devhelp search
rm -rf %{buildroot}%{_datadir}/gtk-doc/html/GStreamer-%{gst_branch}/assets/js/search

# Rename the devhelp docs to include the version
cp -r %{buildroot}%{_datadir}/gtk-doc/html/GStreamer-%{gst_branch}/GStreamer.devhelp2 \
   %{buildroot}%{_datadir}/gtk-doc/html/GStreamer-%{gst_branch}/GStreamer-%{gst_branch}.devhelp2

# Remove duplicates
%fdupes %{buildroot}%{_datadir}

%files
%license LICENSE.BSD LICENSE.CC-BY-SA-4.0 LICENSE.LGPL-2.1 LICENSE.MIT LICENSE.OPL
%doc README.md
%dir %{_datadir}/gtk-doc
%dir %{_datadir}/gtk-doc/html
%{_datadir}/gtk-doc/html/GStreamer-%{gst_branch}/

%changelog
* Wed Apr 30 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.26.1:
  + Update docs.
* Wed Mar 12 2025 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.26.0:
  + Highlights
  - H.266 Versatile Video Coding (VVC) codec support
  - Low Complexity Enhancement Video Coding (LCEVC) support
  - Closed captions: H.264/H.265 extractor/inserter,
    cea708overlay, cea708mux, tttocea708 and more
  - New hlscmafsink, hlssink3, and hlsmultivariantsink; HLS/DASH
    client and dashsink improvements
  - New AWS and Speechmatics transcription, translation and TTS
    services elements, plus translationbin
  - Splitmux lazy loading and dynamic fragment addition support
  - Matroska: H.266 video and rotation tag support, defined
    latency muxing
  - MPEG-TS: support for H.266, JPEG XS, AV1, VP9 codecs and
    SMPTE ST-2038 and ID3 meta; mpegtslivesrc
  - ISO MP4: support for H.266, Hap, Lagarith lossless codecs;
    raw video support; rotation tags
  - SMPTE 2038 ancillary data streams support
  - JPEG XS image codec support
  - Analytics: New TensorMeta; N-to-N relationships; Mtd to carry
    segmentation masks
  - ONVIF metadata extractor and conversion to/from relation
    metas
  - New originalbuffer element that can restore buffers again
    after transformation steps for analytics
  - Improved Python bindings for analytics API
  - Lots of Vulkan integration and Vulkan Video decoder/encoder
    improvements
  - OpenGL integration improvements, esp. in glcolorconvert,
    gldownload, glupload
  - Qt5/Qt6 QML GL sinks now support direct DMABuf import from
    hardware decoders
  - CUDA: New compositor, Jetson NVMM memory support,
    stream-ordered allocator
  - NVCODEC AV1 video encoder element, and nvdsdewarp
  - New Direct3D12 integration support library
  - New d3d12swapchainsink and d3d12deinterlace elements and
    D3D12 sink/source for zero-copy IPC
  - Decklink HDR support (PQ + HLG) and frame scheduling
    enhancements
  - AJA capture source clock handling and signal loss recovery
    improvements
  - RTP and RTSP: New rtpbin sync modes, client-side MIKEY
    support in rtspsrc
  - New Rust rtpbin2, rtprecv, rtpsend, and many new Rust RTP
    payloaders and depayloaders
  - webrtcbin support for basic rollbacks and other improvements
  - webrtcsink: support for more encoders, SDP munging, and a
    built-in web/signalling server
  - webrtcsrc/sink: support for uncompressed audio/video and NTP
    & PTP clock signalling and synchronization
  - rtmp2: server authentication improvements incl. Limelight
    CDN (llnw) authentication
  - New Microsoft WebView2 based web browser source element
  - The GTK3 plugin has gained support for OpenGL/WGL on Windows
  - Many GTK4 paintable sink improvements
  - GstPlay: id-based stream selection and message API
    improvements
  - Real-time pipeline visualization in a browser using a new
    dots tracer and viewer
  - New tracers for tracking memory usage, pad push timings, and
    buffer flow as pcap files
  - VA hardware-acclerated H.266/VVC decoder, VP8 and JPEG
    encoders, VP9/VP8 alpha decodebins
  - Video4Linux2 elements support DMA_DRM caps negotiation now
  - V4L2 stateless decoders implement inter-frame resolution
    changes for AV1 and VP9
  - Editing services: support for reverse playback and audio
    channel reordering
  - New QUIC-based elements for working with raw QUIC streams,
    RTP-over-QUIC (RoQ) and WebTransport
  - Apple AAC audio encoder and multi-channel support for the
    Apple audio decoders
  - cerbero: Python bindings and introspection support; improved
    Windows installer based on WiX5
  - Lots of new plugins, features, performance improvements and
    bug fixes
  + Documentation improvements:
  - Tracer objects information is now included in the
    documentation
  + For more detailed information on this update, please see
    https://gstreamer.freedesktop.org/releases/1.26/
* Mon Feb  3 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.24.12:
  + No changes, stable version bump only
* Tue Jan  7 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.24.11:
  + No changes, stable version bump only.
* Mon Dec  9 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.24.10:
  + No changes, stable version bump only.
* Sun Nov 17 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.24.9:
  + No changes, stable version bump only.
* Mon Sep 23 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.24.8:
  + No changes, stable version bump only.
* Fri Aug 23 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.24.7:
  + Highlighted bugfixes:
  - Fix APE and Musepack audio file and GIF playback with FFmpeg
    7.0
  - playbin3: Fix potential deadlock with multiple playbin3s with
    glimagesink used in parallel
  - qt6: various qmlgl6src and qmlgl6sink fixes and improvements
  - rtspsrc: expose property to force usage of non-compliant
    setup URLs for RTSP servers where the automatic fallback
    doesn't work
  - urisourcebin: gapless playback and program switching fixes
  - v4l2: various fixes
  - va: Fix potential deadlock with multiple va elements used in
    parallel
  - meson: option to disable gst-full for static-library build
    configurations that do not need this
  - Various bug fixes, memory leak fixes, and other stability and
    reliability improvements.
* Wed Aug 14 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.24.6:
  + Highlighted bugfixes:
  - Fix compatibility with FFmpeg 7.0.
  - qmlglsink: Fix failure to display content on recent Android
    devices.
  - adaptivedemux: Fix handling of closed caption streams.
  - cuda: Fix runtime compiler loading with old CUDA tookit.
  - decodebin3 stream selection handling fixes.
  - d3d11compositor, d3d12compositor: Fix transparent background
    mode with YUV output.
  - d3d12converter: Make gamma remap work as intended.
  - h264decoder: Update output frame duration for interlaced
    video when second field frame is discarded.
  - macOS audio device provider now listens to audio devices
    being added/removed at runtime.
  - Rust plugins: audioloudnorm, s3hlssink, gtk4paintablesink,
    livesync and webrtcsink fixes.
  - videoaggregator: preserve features in non-alpha caps for
    subclasses with non-system memory sink caps.
  - vtenc: Fix redistribute latency spam.
  - v4l2: fixes for complex video formats.
  - va: Fix strides when importing DMABUFs, dmabuf handle leaks,
    and blocklist unmaintained Intel i965 driver for encoding.
  - waylandsink: Fix surface cropping for rotated streams.
  - webrtcdsp: Enable multi_channel processing to fix handling of
    stereo streams.
  - Various bug fixes, memory leak fixes, and other stability and
    reliability improvements.
* Fri Jun 28 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.24.5:
  + Highlighted bugfixes:
  - webrtcsink: Support for AV1 via nvav1enc, av1enc or rav1enc
    encoders
  - AV1 RTP payloader/depayloader fixes to work correctly with
    Chrome and Pion WebRTC
  - av1parse, av1dec error handling/robustness improvements
  - av1enc: Handle force-keyunit events properly for WebRTC
  - decodebin3: selection and collection handling improvements
  - hlsdemux2: Various fixes for discontinuities, variant
    switching, playlist updates
  - qml6glsink: fix RGB format support
  - rtspsrc: more control URL handling fixes
  - v4l2src: Interpret V4L2 report of sync loss as video signal
    loss
  - d3d12 encoder, memory and videosink fixes
  - vtdec: more robust error handling, fix regression
  - ndi: support for NDI SDK v6
  - Various bug fixes, memory leak fixes, and other stability and
    reliability improvements
- Please see https://gstreamer.freedesktop.org/releases/1.24/ for
  changes between 1.24.0 and this version and even more in-depth
  info.
* Tue Mar  5 2024 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.24.0:
  * Highlights
  - New Discourse forum and Matrix chat space
  - New Analytics and Machine Learning abstractions and elements
  - Playbin3 and decodebin3 are now stable and the default in
    gst-play-1.0, GstPlay/GstPlayer
  - The va plugin is now preferred over gst-vaapi and has higher
    ranks
  - GstMeta serialization/deserialization and other GstMeta
    improvements
  - New GstMeta for SMPTE ST-291M HANC/VANC Ancillary Data
  - New unixfd plugin for efficient 1:N inter-process
    communication on Linux
  - cudaipc source and sink for zero-copy CUDA memory sharing
    between processes
  - New intersink and intersrc elements for 1:N pipeline
    decoupling within the same process
  - Qt5 + Qt6 QML integration improvements including qml6glsrc,
    qml6glmixer, qml6gloverlay, and qml6d3d11sink elements
  - DRM Modifier Support for dmabufs on Linux
  - OpenGL, Vulkan and CUDA integration enhancements
  - Vulkan H.264 and H.265 video decoders
  - RTP stack improvements including new RFC7273 modes and more
    correct header extension handling in depayloaders
  - WebRTC improvements such as support for ICE consent
    freshness, and a new webrtcsrc element to complement
    webrtcsink
  - WebRTC signallers and webrtcsink implementations for LiveKit
    and AWS Kinesis Video Streams
  - WHIP server source and client sink, and a WHEP source
  - Precision Time Protocol (PTP) clock support for Windows and
    other additions
  - Low-Latency HLS (LL-HLS) support and many other HLS and DASH
    enhancements
  - New W3C Media Source Extensions library
  - Countless closed caption handling improvements including new
    cea608mux and cea608tocea708 elements
  - Translation support for awstranscriber
  - Bayer 10/12/14/16-bit depth support
  - MPEG-TS support for asynchronous KLV demuxing and segment
    seeking, plus various new muxer features
  - Capture source and sink for AJA capture and playout cards
  - SVT-AV1 and VA-API AV1 encoders, stateless AV1 video decoder
  - New uvcsink element for exporting streams as UVC camera
  - DirectWrite text rendering plugin for windows
  - Direct3D12-based video decoding, conversion, composition, and
    rendering
  - AMD Advanced Media Framework AV1 + H.265 video encoders with
    10-bit and HDR support
  - AVX/AVX2 support and NEON support on macOS on Apple ARM64
    CPUs via new liborc
  - GStreamer C# bindings have been updated
  - Rust bindings improvements and many new and improved Rust
    plugins
  - Rust plugins now shipped in packages for all major platforms
    including Android and iOS
  - Lots of new plugins, features, performance improvements and
    bug fixes
  * For more detailed information on this update, please see
    https://gstreamer.freedesktop.org/releases/1.24/
* Thu Feb  1 2024 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.22.9:
  + No changelog provided by upstream.
* Thu Jan  4 2024 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.22.8:
  + No changelog provided by upstream.
* Wed Nov 15 2023 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.22.7:
  + No changelog provided by upstream.
* Fri Sep 22 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.6:
  + No changelog provided by upstream.
* Tue Jul 25 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.5:
  + No changelog provided by upstream.
* Mon Jun 26 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.4:
  + No changelog provided by upstream.
* Wed May 24 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.3:
  + No changelog provided by upstream.
* Wed Apr 12 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.2:
  + No changelog provided by upstream.
* Thu Mar  9 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.1:
  + No changelog provided by upstream.
* Thu Jan 26 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.0:
  + Please see changes in gstreamer main package, major version
    bump.
* Fri Dec 23 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.20.5:
  + No changelog provided by upstream.
* Sat Oct 22 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.20.4:
  + No changelog provided by upstream.
* Wed Jun 22 2022 Aaron Stern <ukbeast89@protonmail.com>
- Update to version 1.20.3:
  + No changelog provided by upstream.
* Mon May  9 2022 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.20.2:
  + No changelog provided by upstream.
* Sat Mar 19 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.20.1:
  + Various updates in different sub-modules.
* Wed Feb  9 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.20.0:
  + Hardware-accelerated GPU plugins will now no longer always list
    all the element variants for all available GPUs, since those
    are system-dependent and it's confusing for users to see those
    in the documentation just because the GStreamer developer who
    generated the docs had multiple GPUs to play with at the time.
    Instead just show the default elements.
* Wed Feb  9 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.18.6:
  + Unified documentation containing tutorials, API docs, plugin
    docs, etc. all under one roof, shipped in form of a
    documentation release tarball containing both devhelp and html
    documentation.
* Wed Sep 15 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Initial packaging for openSUSE, version 1.18.5
